
// Asounding Audio Engine for iOS
// Copyright (c) 2011  Michel Fortin
//
// You must obtain a comercial license for using this code in software
// distributed not under the GNU GPL. See <http://michelf.com/asounding/>.
//
// This program is free software: you can redistribute it and/or modify it 
// under the terms of the GNU General Public License as published by the Free 
// Software Foundation, either version 3 of the License, or (at your option) 
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT 
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
// more details.
//
// You should have received a copy of the GNU General Public License along 
// with this program. If not, see <http://www.gnu.org/licenses/>.
//
// As a special exception to the GPL, you may distribute a compiled 
// application including this file on the Apple App Store for iOS without 
// having to redistribute the digital keys needed to reproduce the digital 
// signature needed to run an application on an iOS device. This exception 
// does not invalidate any other requirements put on you by the GPL.

#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>


/*!
 @abstract   A music for playing in the background by the ASNEngine.
 */
@interface ASNMusic : NSObject
{
	AVAudioPlayer*			musicPlayer;
}

/*! @group  Initializing a music object */
/*!
 @abstract   Initialize with music from the given URL.
 @param      url  URL to read the music from.
 @param      outError  Error object in case music couldn't be loaded.
 @discussion The selected audio file must be in a format understood by 
 CoreAudio. This includes AIFF, WAV, MP3, AAC, and CAF files. Compressed
 formats such as MP3 and AAC will benefit from the hardware decoder when
 available.
 */
- (id)initWithContentsOfURL:(NSURL *)url error:(NSError **)outError;

/*! @group  Setting Playback Parameters */
/*!
 @abstract   The duration of the music.
 */
@property(readonly) NSTimeInterval duration;
/*!
 @abstract   Number of times this music will repeat.
 @discussion Use value -1 to repeat indefinitely.
 */
@property(assign) NSInteger numberOfLoops;

// For internal use only:
- (AVAudioPlayer *)avPlayer;

@end
