
// Demo for Asounding Audio Engine for iOS
//
// You must obtain a comercial license for using this code in software
// distributed not under the GNU GPL. See <http://michelf.com/asounding/>.
//
// This program is free software: you can redistribute it and/or modify it 
// under the terms of the GNU General Public License as published by the Free 
// Software Foundation, either version 3 of the License, or (at your option) 
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT 
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
// more details.
//
// You should have received a copy of the GNU General Public License along 
// with this program. If not, see <http://www.gnu.org/licenses/>.
//
// As a special exception to the GPL, you may distribute a compiled 
// application including this file on the Apple App Store for iOS without 
// having to redistribute the digital keys needed to reproduce the digital 
// signature needed to run an application on an iOS device. This exception 
// does not invalidate any other requirements put on you by the GPL.

#import "SoundEffectsTabController.h"


@implementation SoundEffectsTabController

- (void)dealloc {
    [super dealloc];
}

- (IBAction)enableSoundsChange {
	[ASNEngine sharedEngine].soundsEnabled = enableSoundsSwitch.on;
}

- (void)updateControls {
	ASNEngine *engine = [ASNEngine sharedEngine];
	enableSoundsSwitch.on = engine.soundsEnabled;
}

@end


@implementation SoundSourceController

- (void)awakeFromNib {
	source = [ASNSource new];
	
	// Preload sounds
	NSURL *sound1URL = [[NSBundle mainBundle] URLForResource:@"extend" withExtension:@"caf"];
	sound1 = [[ASNSound alloc] initWithContentOfURL:sound1URL];

	NSURL *sound2URL = [[NSBundle mainBundle] URLForResource:@"small_enemy_destroyed" withExtension:@"caf"];
	sound2 = [[ASNSound alloc] initWithContentOfURL:sound2URL];
	
	[self updateControls];
}

- (void)dealloc {
	[source release];
	[sound1 release];
	[sound2 release];
	[super dealloc];
}

- (IBAction)playSound1 {
	[source stop];
	source.sound = sound1;
	[source play];
}
- (IBAction)playSound2 {
	[source stop];
	source.sound = sound2;
	[source play];
}
- (IBAction)stop {
	[source stop];
}

- (IBAction)changeLoop {
	source.looping = loopSwitch.on;
}

- (IBAction)changePitch {
	// Slider goes from -1.0 to 1.0, change to pitch 
	// between 0.5 and 2.0 to evenly represent tones.
	ALfloat pitchValue = exp2(pitchSlider.value);
	source.pitch = pitchValue;
	[self updatePitchLabel];
}


- (void)updateControls {
	loopSwitch.on = source.looping;

	pitchSlider.value = log2(source.pitch);
	[self updatePitchLabel];
}

- (void)updatePitchLabel {
	pitchValueLabel.text = [NSString stringWithFormat:@"%.2f", source.pitch];
}

@end